vc-processors contains the types and builtin external processors for venus-cluster/venus-worker.
This crate aims at providing an easy-to-use, buttery-included framework for third-party developers to implement customized external processors.
This crate could be used to:
- interact with builtin external processors in venus-worker.
- wrap close-source processors for builtin tasks in venus-worker.
- implement any customized external processors for other usecases.
The examples show more details about the usages.
Modules
- b64serde
- builtin
- Built-in tasks & processors
- core
- This module provides the most important types and abstractions
- fil_
proofs - This module provides types and apis re-exported from rust-fil-proofs
- sys
- This module provides some operating system level APIs or bindings of native libraries