Module core

This module provides the most important types and abstractions

Modules

ext
This module provides wrappers to construct task producer & consumer. The producer sends tasks via stdin of the consumer, which should be a sub-process.

Traits

Processor
Processor of a specific task type
Task
Task of a specific stage, with Output & Error defined