pub struct ProducerBuilder<HP, HF> { /* private fields */ }Expand description
Builder for Producer
Implementations
Sourceimpl<HP, HF> ProducerBuilder<HP, HF>
impl<HP, HF> ProducerBuilder<HP, HF>
Sourcepub fn new(bin: PathBuf, args: Vec<String>) -> Self
pub fn new(bin: PathBuf, args: Vec<String>) -> Self
Construct a new builder with the given binary path & args.
Sourcepub fn inherit_envs(self, yes: bool) -> Self
pub fn inherit_envs(self, yes: bool) -> Self
Set if we should inherit envs from the parent process, default is true.
Sourcepub fn env(self, name: String, value: String) -> Self
pub fn env(self, name: String, value: String) -> Self
Set a pair of env name & value for the child.
Sourcepub fn stable_timeout(self, timeout: Duration) -> Self
pub fn stable_timeout(self, timeout: Duration) -> Self
Set the timeout before we wait for the child process to be stable, default is None, thus we would block util the child gives the ready message.
Sourcepub fn hook_prepare(self, f: HP) -> Self
pub fn hook_prepare(self, f: HP) -> Self
Set a prepare hook, which will be called before the Producer send the task to the child.
Sourcepub fn hook_finalize(self, f: HF) -> Self
pub fn hook_finalize(self, f: HF) -> Self
Set a finalize hook, which will be called before the Processor::process returns.
Sourcepub fn auto_restart(self, auto_restart: bool) -> Self
pub fn auto_restart(self, auto_restart: bool) -> Self
Set auto restart for child process