Module vc_processors::core
source · [−]Expand description
This module provides the most important types and abstractions
Modules
This module provides wrappers to construct task producer & consumer. The producer sends tasks via stdin of the consumer, which should be a sub-process.