Module vc_processors::core::ext
source · [−]Expand description
This module provides wrappers to construct task producer & consumer. The producer sends tasks via stdin of the consumer, which should be a sub-process.
Structs
Request contains the required data to be sent to the consumer.
Response contains the output for the specific task, and error message if exists.
Functions
Starts the consumer. In most cases, this is used in a sub-process Please be awrae that you should let the logs output into stderr, or just disable all logs from this process, otherwise the producer colud be confused.